summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
-rw-r--r--ACE/ACE-INSTALL.html9
-rw-r--r--ACE/VERSION.txt (renamed from ACE/VERSION)0
-rwxr-xr-xACE/bin/ace-install8
-rwxr-xr-xACE/bin/generate_doxygen.pl14
-rwxr-xr-xACE/bin/make_release.py17
-rw-r--r--TAO/VERSION.txt (renamed from TAO/VERSION)0
6 files changed, 18 insertions, 30 deletions
diff --git a/ACE/ACE-INSTALL.html b/ACE/ACE-INSTALL.html
index 5f832c0ac0f..e00f78fa845 100644
--- a/ACE/ACE-INSTALL.html
+++ b/ACE/ACE-INSTALL.html
@@ -1662,14 +1662,7 @@ with "<b>Windows Users:</b>" in addition to the rest of the instructions. In
addition to the Windows version of the Android NDK, you will also need MinGW
for Unix utilities that ACE needs. Install <a href="http://www.mingw.org">
MinGW</a> and the <code>mingw-developer-toolkit-bin</code> meta package using
-the MinGW package manager.
-
-<p>You will also have to delete the <code>%ACE_ROOT%\VERSION</code> and
-<code>%TAO_ROOT%\VERSION</code> files. The <code>version</code> C++ standard
-header is used by the toolchain's standard library and on Windows filenames are
-case insensitive in many cases, so that leads to the compiler failing when it
-tries to use ACE and TAO's VERSION files when <code>version</code> is included.
-</p>
+the MinGW package manager.</p>
</div>
<h3><a name="android-toolchain">Generating a Toolchain</a></h3>
diff --git a/ACE/VERSION b/ACE/VERSION.txt
index b9fe9066970..b9fe9066970 100644
--- a/ACE/VERSION
+++ b/ACE/VERSION.txt
diff --git a/ACE/bin/ace-install b/ACE/bin/ace-install
index 312fcb243ec..8bf684a35e0 100755
--- a/ACE/bin/ace-install
+++ b/ACE/bin/ace-install
@@ -389,10 +389,10 @@ if [ $install -ne 0 ]; then
##########################################
# determine final target directories
- ACE_VER=`head -n 1 $ACE_ROOT/VERSION | sed -e 's/^[^0-9]*//' -e 's/[, ].*//'`
+ ACE_VER=`head -n 1 $ACE_ROOT/VERSION.txt | sed -e 's/^[^0-9]*//' -e 's/[, ].*//'`
ACE_DIR="$ACE_DEST/ACE-$ACE_VER"; export ACE_DIR
- TAO_VER=`head -n 1 $ACE_ROOT/TAO/VERSION | sed -e 's/^[^0-9]*//' -e 's/[, ].*//'`
+ TAO_VER=`head -n 1 $ACE_ROOT/TAO/VERSION.txt | sed -e 's/^[^0-9]*//' -e 's/[, ].*//'`
TAO_DIR="$ACE_DEST/TAO-$TAO_VER"; export ACE_DIR
##########################################
@@ -417,7 +417,7 @@ if [ $install -ne 0 ]; then
# copy TAO stuff
cd $ACE_ROOT/TAO
- cp VERSION $TAO_DIR/$ACE_ARCH/TAO-VERSION
+ cp VERSION.txt $TAO_DIR/$ACE_ARCH/TAO-VERSION
# copy TAO includes
echo "Copying include files..."
@@ -459,7 +459,7 @@ if [ $install -ne 0 ]; then
# copy ACE stuff
cd $ACE_ROOT
- cp VERSION $ACE_DIR/$ACE_ARCH/ACE-VERSION
+ cp VERSION.txt $ACE_DIR/$ACE_ARCH/ACE-VERSION
# copy ACE includes
echo "Copying include files..."
diff --git a/ACE/bin/generate_doxygen.pl b/ACE/bin/generate_doxygen.pl
index 2296438b59f..1effd5a0684 100755
--- a/ACE/bin/generate_doxygen.pl
+++ b/ACE/bin/generate_doxygen.pl
@@ -27,16 +27,16 @@ if (!defined $DANCE_ROOT) {
$is_release = 0;
$exclude_ace = 0;
-$exclude_tao = !-r "$TAO_ROOT/VERSION";
-$exclude_ciao = !-r "$CIAO_ROOT/VERSION";
-$exclude_dance = !-r "$DANCE_ROOT/VERSION";
+$exclude_tao = !-r "$TAO_ROOT/VERSION.txt";
+$exclude_ciao = !-r "$CIAO_ROOT/VERSION.txt";
+$exclude_dance = !-r "$DANCE_ROOT/VERSION.txt";
$verbose = 0;
$perl_path = '/usr/bin/perl';
$html_output_dir = '.';
$footer = '';
$dds = 0;
-if (defined $DDS_ROOT && -r "$DDS_ROOT/VERSION") {
+if (defined $DDS_ROOT && -r "$DDS_ROOT/VERSION.txt") {
$dds_path = Cwd::abs_path($DDS_ROOT);
$cwd_path = Cwd::abs_path(getcwd());
if ($dds_path eq $cwd_path) {
@@ -96,11 +96,11 @@ if (!-r "$ACE_ROOT/ace/config.h") {
$wrote_configh = 1;
}
-&generate_doxy_files ('ACE', " $ACE_ROOT", " $ACE_ROOT/VERSION", @ACE_DOCS) if (!$exclude_ace);
-&generate_doxy_files ('TAO', " $TAO_ROOT", " $TAO_ROOT/VERSION", @TAO_DOCS) if (!$exclude_tao);
+&generate_doxy_files ('ACE', " $ACE_ROOT", " $ACE_ROOT/VERSION.txt", @ACE_DOCS) if (!$exclude_ace);
+&generate_doxy_files ('TAO', " $TAO_ROOT", " $TAO_ROOT/VERSION.txt", @TAO_DOCS) if (!$exclude_tao);
&generate_doxy_files ('CIAO', " $CIAO_ROOT", " $CIAO_ROOT/VERSION", @CIAO_DOCS) if (!$exclude_ciao);
&generate_doxy_files ('DANCE'," $DANCE_ROOT", " $DANCE_ROOT/VERSION", @DANCE_DOCS) if (!$exclude_dance);
-&generate_doxy_files ('DDS', "$DDS_ROOT", " $DDS_ROOT/VERSION", @DDS_DOCS) if $dds;
+&generate_doxy_files ('DDS', "$DDS_ROOT", " $DDS_ROOT/VERSION.txt", @DDS_DOCS) if $dds;
unlink "$ACE_ROOT/ace/config.h" if $wrote_configh;
diff --git a/TAO/VERSION b/TAO/VERSION.txt
index f4779e6769e..f4779e6769e 100644
--- a/TAO/VERSION
+++ b/TAO/VERSION.txt
diff --git a/ACE/bin/make_release.py b/ACE/bin/make_release.py
index 8415b2185b5..6a0b79e4396 100755
--- a/ACE/bin/make_release.py
+++ b/ACE/bin/make_release.py
@@ -183,18 +183,16 @@ def check_workspace ():
def update_version_files (component):
""" Updates the version files for a given component. This includes
- Version.h, the PRF, and the VERSION file."""
+ Version.h, the PRF, and the VERSION.txt file."""
global comp_versions, opts, release_date
vprint ("Updating version files for " + component)
- import re
-
retval = list ()
- ## Update component/VERSION
- with open (component + "/VERSION", "r+") as version_file:
+ ## Update component/VERSION.txt
+ with open (component + "/VERSION.txt", "r+") as version_file:
new_version = re.sub (component + " version .*",
"%s version %s, released %s" % (component,
comp_versions[component + "_version"],
@@ -210,7 +208,7 @@ def update_version_files (component):
vprint ("Updating Version.h for " + component)
- retval += [component + "/VERSION"]
+ retval += [component + "/VERSION.txt"]
## Update component/component/Version.h
version_header = """
@@ -309,7 +307,6 @@ def update_debianbuild ():
global comp_versions
- import re
from os import listdir
files = list ()
@@ -419,20 +416,18 @@ def create_changelog (component):
return ["%s/ChangeLogs/%s-%s" % (component, component, comp_versions[component + "_version_"])]
def get_comp_versions (component):
""" Extracts the current version number from the VERSION
file and increments it appropriately for the release type
requested."""
vprint ("Detecting current version for " + component)
- import re
-
global old_comp_versions, comp_versions, opts
micro = re.compile ("version (\d+)\.(\d+)\.(\d+)")
minor = re.compile ("version (\d+)\.(\d+)[^\.]")
major = re.compile ("version (\d+)[^\.]")
- with open (component + "/VERSION") as version_file:
+ with open (component + "/VERSION.txt") as version_file:
for line in version_file:
match = None
@@ -419,20 +416,18 @@ def create_changelog (component):
return ["%s/ChangeLogs/%s-%s" % (component, component, comp_versions[component + "_version_"])]
def get_comp_versions (component):
- """ Extracts the current version number from the VERSION
+ """ Extracts the current version number from the VERSION.txt
file and increments it appropriately for the release type
requested."""